@@ -1,8 +1,11 @@
 from .little_mallet_wrapper import (
+  print_dataset_stats,
   process_string,
+  import_data,
   train_topic_model,
   load_topic_keys,
   load_topic_distributions,
+  get_top_docs,
   plot_categories_by_topics_heatmap,
   plot_categories_by_topic_boxplots,
   divide_training_data,
